smartcard.sw.SWExceptions.CheckingErrorException

# ``smartcard`.`sw`.`SWExceptions`.`CheckingErrorException``

exception documentation

`class CheckingErrorException(SWException):`

View In Hierarchy

Raised when a checking error is detected from sw1, sw2. Examples of checking error: sw1=67 to 6F (ISO781604).

Method | `__init__` | Undocumented

Inherited from `SWException`:

Method | `__str__` | Undocumented
Instance Variable | `data` | response apdu sw1
Instance Variable | `message` | response apdu data
Instance Variable | `sw1` | response apdu sw2
Instance Variable | `sw2` | Undocumented

def __init__(self, data, sw1, sw2, message=''):
overrides `smartcard.sw.SWExceptions.SWException.__init__`

Undocumented